@@ -29,7 +29,8 @@ This AWS Solutions Construct implements an AWS CloudFront fronting an Amazon API
 Here is a minimal deployable pattern definition:
 
 ```javascript
-const { defaults } = require('@aws-solutions-constructs/core');
+const api = require('@aws-cdk/aws-apigateway');
+const lambda = require("@aws-cdk/aws-lambda");
 const { CloudFrontToApiGateway } = require('@aws-solutions-constructs/aws-cloudfront-apigateway');
 
 const stack = new Stack();
@@ -40,12 +41,22 @@ const lambdaProps: lambda.FunctionProps = {
     handler: 'index.handler'
 };
 
-const func = defaults.deployLambdaFunction(stack, lambdaProps);
+const lambdafunction = new lambda.Function(stack, 'LambdaFunction', lambdaProps);
 
-const _api = defaults.RegionalApiGateway(stack, func);
+const apiGatewayProps: api.LambdaRestApiProps = {
+        handler: lambdafunction,
+        endpointConfiguration: {
+            types: [api.EndpointType.REGIONAL]
+        },
+        defaultMethodOptions: {
+            authorizationType: api.AuthorizationType.NONE
+        }
+};
+
+const apiGateway = new api.LambdaRestApi(scope, 'LambdaRestApi', apiGatewayProps);
 
 new CloudFrontToApiGateway(stack, 'test-cloudfront-apigateway', {
-    existingApiGatewayObj: _api
+    existingApiGatewayObj: apiGateway
 });
 
 ```
@@ -210,9 +221,7 @@ class CloudFrontToApiGatewayProps:
             "existing_api_gateway_obj": existing_api_gateway_obj,
         }
         if cloud_front_distribution_props is not None:
-            self._values[
-                "cloud_front_distribution_props"
-            ] = cloud_front_distribution_props
+            self._values["cloud_front_distribution_props"] = cloud_front_distribution_props
         if insert_http_security_headers is not None:
             self._values["insert_http_security_headers"] = insert_http_security_headers
 
